@@ -1,20 +1,11 @@
 #!/usr/bin/env python
 # GPL. (C) 2007-2012 Paolo Patruno.
 
-from __future__ import division
-from __future__ import print_function
-from builtins import str
-from builtins import range
-from builtins import object
-from past.utils import old_div
 import dbus
 import time
 import datetime
 import os,sys
-if sys.version_info[0] == 3:
-    from gi.repository import GObject as gobject
-else:
-    import gobject
+from gi.repository import GObject as gobject
 
 from . import settings
 from dbus.mainloop.glib import DBusGMainLoop
@@ -83,7 +74,7 @@ class mediaplayer(object):
 
         DBusGMainLoop(set_as_default=True)
 
-        uris = get_players_uri(pattern=".*"+player+"$",busaddress=busaddress)
+        uris = list(get_players_uri(pattern=".*"+player+"$",busaddress=busaddress))
 
         if len(uris) >0 :
             uri=uris[0]
@@ -102,19 +93,29 @@ class mediaplayer(object):
             self.tl = TrackList(dbus_interface_info={'dbus_uri': uri,'dbus_session':self.bus})
         else:
             self.tl = None
-
+            
     def __str__(self):
         return self.play.PlaybackStatus
-    
+
 
     def play_ifnot(self):
         '''
         start playing if not.
         '''
         # I check if mediaplayer is playing .... otherside I try to play
+        # when the player change media file there is a little time it is in stop state
+        # so we have to check it more times to do not repeat to play twice the same media file
 
-        if (not self.isplaying()):
-            self.play.Play()
+        if (self.isplaying()):
+            return
+        time.sleep(2)
+        if (self.isplaying()):
+            return
+        time.sleep(2)
+        if (self.isplaying()):
+            return
+        
+        self.play.Play()
 
     def isplaying(self):
         '''
@@ -125,7 +126,7 @@ class mediaplayer(object):
 
 
 
-    def get_playlist_securepos(self,securesec=10):
+    def get_playlist_securepos(self,securesec=20):
         '''
         Try to secure that there are some time (securesec) to complete all operations in time:
         if the player change song during operation will be a big problem
@@ -363,8 +364,8 @@ class mediaplayer(object):
             "file": file,
             "title": title,
             "artist": artist,
-            "mtimelength": int(round(old_div(mtimelength,1000.))),
-            "mtimeposition": int(round(old_div(mtimeposition,1000.)))
+            "mtimelength": int(round(mtimelength/1000.)),
+            "mtimeposition": int(round(mtimeposition/1000.))
             }
 
         return mymeta
