@@ -27,14 +27,6 @@
 # everywhere we change the tracklist
 # we use this in autoplayergui to update the tracklist
 
-from __future__ import division
-from __future__ import print_function
-from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
-from builtins import str
-from builtins import object
-from past.utils import old_div
 import sys, time, _thread
 import tempfile,os
 
@@ -269,9 +261,9 @@ class AutoPlayer(dbus.service.Object):
     def __Position(self):
       position = self.player.position()
       if position is None:
-        return dbus.Int64(0)
+        return dbus.UInt64(0)
       else:
-        return dbus.Int64(position)
+        return dbus.UInt64(position)
 
     def __CanPlay(self):
         if self.player.playlist.current is None :
@@ -523,7 +515,7 @@ class AutoPlayer(dbus.service.Object):
                 myattr=None
               if myattr is not None:
                 if key == "mpris:length":
-                  myattr=int(round(old_div(myattr,1000.)))
+                  myattr=dbus.UInt64(round(myattr/1000.))
                 meta[key]=myattr
       
             metadata.append(dbus.Dictionary(meta, signature='sv'))
@@ -551,6 +543,12 @@ class Player(object):
     #self.player = gst.element_factory_make("playbin2", "playbin2")
     Gst.init(None)
     self.player = Gst.ElementFactory.make("playbin", None)
+    try:
+      self.rgvolume = Gst.ElementFactory.make("rgvolume", "rgvolume")
+      self.player.set_property('audio-filter', self.rgvolume)
+    except:
+      logging.error( "setting replaygain player plugin")
+
     self.playmode = "Stopped"
     self.recoverplaymode = "Stopped"
     self.statuschanged = False
@@ -609,34 +607,34 @@ class Player(object):
 
 
     # ReplayGain
-    if (Gst.ElementFactory.find('rgvolume') and
-        Gst.ElementFactory.find('rglimiter')):
-      self.audioconvert = Gst.ElementFactory.make('audioconvert',None)
-
-      self.rgvolume = Gst.ElementFactory.make('rgvolume',None)
-      self.rgvolume.set_property('album-mode', False)
-      self.rgvolume.set_property('pre-amp', 0)
-      self.rgvolume.set_property('fallback-gain', 0)
-
-      self.rgvolume.set_property('headroom',0)
-      self.rgvolume.set_property('pre-amp',0)
-
-      self.rglimiter = Gst.ElementFactory.make('rglimiter',None)
-      self.rglimiter.set_property('enabled', True)
-
-      self.rgfilter = Gst.Bin()
-      self.rgfilter.add(self.rgvolume)
-      self.rgfilter.add(self.rglimiter)
-      self.rgvolume.link(self.rglimiter)
-      self.rgfilter.add_pad(Gst.GhostPad.new('sink',
-                self.rgvolume.get_static_pad('sink')))
-      self.rgfilter.add_pad(Gst.GhostPad.new('src',
-                self.rglimiter.get_static_pad('src')))
-      try:
-        self.player.set_property('audio-filter', self.rgfilter)
-      except:
-        logging.error( "setting replaygain player")
-        #raise Exception("cannot manage replaygain!")
+    #if (Gst.ElementFactory.find('rgvolume') and
+    #    Gst.ElementFactory.find('rglimiter')):
+    #  self.audioconvert = Gst.ElementFactory.make('audioconvert',None)
+    #
+    #  self.rgvolume = Gst.ElementFactory.make('rgvolume',None)
+    #  self.rgvolume.set_property('album-mode', False)
+    #  self.rgvolume.set_property('pre-amp', 0)
+    #  self.rgvolume.set_property('fallback-gain', 0)
+    #
+    #  self.rgvolume.set_property('headroom',0)
+    #  self.rgvolume.set_property('pre-amp',0)
+    #
+    #  self.rglimiter = Gst.ElementFactory.make('rglimiter',None)
+    #  self.rglimiter.set_property('enabled', True)
+    #
+    #  self.rgfilter = Gst.Bin()
+    #  self.rgfilter.add(self.rgvolume)
+    #  self.rgfilter.add(self.rglimiter)
+    #  self.rgvolume.link(self.rglimiter)
+    #  self.rgfilter.add_pad(Gst.GhostPad.new('sink',
+    #            self.rgvolume.get_static_pad('sink')))
+    #  self.rgfilter.add_pad(Gst.GhostPad.new('src',
+    #            self.rglimiter.get_static_pad('src')))
+    #  try:
+    #    self.player.set_property('audio-filter', self.rgfilter)
+    #  except:
+    #    logging.error( "setting replaygain player")
+    #    #raise Exception("cannot manage replaygain!")
         
 
 #    TODO replaygain
@@ -812,7 +810,7 @@ class Player(object):
     logging.info("seek")
     try:
       pos_int = self.player.query_position(Gst.Format.TIME)[1]
-      pos_int =old_div(pos_int,1000) + t
+      pos_int =int(pos_int/1000) + t
       logging.info("seek %s" % str(pos_int))
       self.setposition(self.playlist.current,pos_int)
       return pos_int
@@ -868,7 +866,7 @@ class Player(object):
     if ret == Gst.StateChangeReturn.FAILURE:
         logging.error( "Unable to set the pipeline to the READY state.")
 
-
+        
   def play(self):
     logging.info( "play")
     self.recoverplaymode = "Playing"
@@ -928,7 +926,7 @@ class Player(object):
       logging.warning( "in query_position:"+str(e) )
       return None
 			    
-    return int(round(old_div(pos_int,1000.)))
+    return int(round(pos_int/1000.))
 
 
   def printinfo(self):
@@ -989,8 +987,8 @@ class Player(object):
     time.sleep(1)
     logging.info ( "recover last status from disk: position %s" % self.playlist.position)
     if self.playlist.position is not None:
-      logging.info ( "set current %s and position %s " % (self.playlist.current,int(round(old_div(self.playlist.position,1000.)))))
-      self.setposition(self.playlist.current,int(round(old_div(self.playlist.position,1000.))))
+      logging.info ( "set current %s and position %s " % (self.playlist.current,int(round(self.playlist.position/1000.))))
+      self.setposition(self.playlist.current,int(round(self.playlist.position/1000.)))
     if self.starttoplay:
       time.sleep(1)
       self.play()
