@@ -2,14 +2,6 @@
 # -*- coding: utf-8 -*-
 # GPL. (C) 2007-2009 Paolo Patruno.
 
-from __future__ import division
-from __future__ import print_function
-from __future__ import absolute_import
-from builtins import zip
-from builtins import str
-from builtins import range
-from past.utils import old_div
-from builtins import object
 from .autoradio_config import *
 
 from .gest_program import *
@@ -19,7 +11,7 @@ from .gest_playlist import *
 from .gest_palimpsest import *
 
 
-class schedule(object):
+class schedule:
     """
     Single schedule object
     attributes:
@@ -128,7 +120,7 @@ class schedule(object):
     def get_datetdone(self):
         return self.emission_done
     def get_isfuture(self):
-        return self.future(datetime.now())
+        return self.future(datetime.now(tz=None))
 
     djobj=property(get_djobj)
     title=property(get_title)
@@ -144,7 +136,11 @@ class schedules(list):
     """
     multiple schedule object
     """
-
+    def __init__(self, *args, **kwargs):
+        super(schedules, self).__init__(*args, **kwargs)
+        self.districatimes=0
+        
+        
     def districa(self):
         '''
         english:
@@ -159,7 +155,9 @@ class schedules(list):
         logging.debug("execute districa")
 
         needrecompute=False
-
+        recomputedtimes=0
+        self.districatimes += 0
+        
         #Spots
         #v=0
         for v,schedulej in enumerate(self):
@@ -185,7 +183,7 @@ class schedules(list):
                     length=schedule.length
                     type=schedule.type
                     endscheduledatetime=scheduledatetime+timedelta(seconds=length)
-                    halfscheduledatetime=scheduledatetime+timedelta(seconds=old_div(length,2))
+                    halfscheduledatetime=scheduledatetime+timedelta(seconds=int(length/2))
 
                     if (type == "spot" or type == "playlist" or type == "jingle" ): continue
 
@@ -265,7 +263,7 @@ class schedules(list):
                     length=schedule.adjustedlength
                     type=schedule.type
                     endscheduledatetime=scheduledatetime+timedelta(seconds=length)
-                    halfscheduledatetime=scheduledatetime+timedelta(seconds=old_div(length,2))
+                    halfscheduledatetime=scheduledatetime+timedelta(seconds=int(length/2))
 
                     if (type == "spot" or type == "playlist" or type == "jingle" ): continue
 
@@ -364,7 +362,7 @@ class schedules(list):
         # time constants
 
         #this is the first and last time that I set the current time
-        if now is None : now=datetime.now()
+        if now is None : now=datetime.now(tz=None)
 
         spots=gest_spot(now,minelab,playlistdir)
 
@@ -436,7 +434,9 @@ class schedules(list):
 
         self.get_all(now,genfile)
         while self.districa():
-            pass
+            if (self.districatimes >= 20 ):
+                logging.error("districa do not converge: too many programs in few time")
+                break
         self.purge()
         self.sort()
         
@@ -445,8 +445,8 @@ class schedules(list):
 
 
 class palimpsest(object):
-
-
+    
+    
     def __init__ (self,title=None,datetime_start=None,datetime_end=None,
                   code=None,type=None,subtype=None,production=None,note=None):
         """
@@ -461,10 +461,51 @@ class palimpsest(object):
         self.production=production
         self.note=note
 
+    def __lt__(self,b):
 
+        #check start datetime
+
+        if self.datetime_start is None and b.datetime_start is None :
+            return False
+    
+        if self.datetime_start is None :
+            return True
+    
+        if b.datetime_start is None :
+            return False
+    
+
+        if  self.datetime_start == b.datetime_start :
+
+            #check end datetime
+            if self.datetime_end is None and b.datetime_end is None :
+                return False
+    
+            if self.datetime_end is None :
+                return Frue
+    
+            if b.datetime_end is None :
+                return False
+            
+            if  self.datetime_end == b.datetime_end :
+                return False
+            elif   self.datetime_end < b.datetime_end :
+                return True
+            elif   self.datetime_end > b.datetime_end :
+                return False
+
+
+        elif   self.datetime_start < b.datetime_start :
+            return True
+        elif   self.datetime_start > b.datetime_start :
+            return False
+
+
+        
+        
     def __cmp__ (self, b):
 
-
+        
         #check start datetime
 
         if self.datetime_start is None and b.datetime_start is None :
@@ -543,7 +584,7 @@ class dates(object):
     def __init__(self,datetime_start, datetime_end,step):
 
         self.step=step
-        self.datetime_start=datetime_start-self.step
+        self.datetime_start=datetime_start
         self.datetime_end=datetime_end
 
 
@@ -587,7 +628,7 @@ class palimpsests(list):
                 type=program.show.type.type
                 subtype=program.show.type.subtype
                 production=program.show.production
-                note=""
+                note=program.show.description
 
                 if pdatetime_start >= datetime_start and pdatetime_end < datetime_end :
 
@@ -629,7 +670,7 @@ class palimpsests(list):
 
             if self[i].datetime_end != self[i+1].datetime_start:
 
-                dtmean=self[i].datetime_end+(old_div((self[i+1].datetime_start-self[i].datetime_end),2))
+                dtmean=self[i].datetime_end+((self[i+1].datetime_start-self[i].datetime_end)/2)
 
                 self[i].datetime_end=dtmean
                 self[i+1].datetime_start=dtmean
