@@ -1,9 +1,6 @@
 #!/usr/bin/env python
 # GPL. (C) 2007-2009 Paolo Patruno.
 
-from __future__ import print_function
-from __future__ import absolute_import
-from builtins import object
 import os
 os.environ['DJANGO_SETTINGS_MODULE'] = 'autoradio.settings'
 from django.conf import settings
@@ -22,7 +19,7 @@ from .programs.models import Configure
 import mutagen
 import os
 
-class gest_program(object):
+class gest_program:
 
     def __init__ (self,now,minelab):
         """init of program application:
@@ -72,7 +69,7 @@ class gest_program(object):
             firth=True
             for enclosure in schedule.episode.enclosure_set.order_by('id'):
                 logging.debug("PROGRAM: files: %s", enclosure.file.path)
-                ar_filename=enclosure.file.path.encode("UTF-8")
+                ar_filename=enclosure.file.path
                 ar_url=enclosure.file.url
                 ar_title=schedule.episode.show.title+" / "\
                     +schedule.episode.title+" / "\
