@@ -2,9 +2,6 @@
 # This Python file uses the following encoding: utf-8
 # GPL. (C) 2007-2009 Paolo Patruno.
 
-from __future__ import print_function
-from __future__ import absolute_import
-from builtins import object
 import os, sys
 os.environ['DJANGO_SETTINGS_MODULE'] = 'autoradio.settings'
 from django.conf import settings
@@ -91,16 +88,16 @@ class gest_spot(object):
             self.ar_spots_in_fascia=self.count_spots()
             self.ar_filename,self.ar_url=self.get_fascia_playlist_media(genfile)
 
-            self.ar_scheduledatetime=datetime.datetime.combine(self.oggi, fascia.emission_time)
+            self.ar_scheduledatetime=datetime.datetime.combine(self.oggi, fascia.emission_time,tzinfo=None)
 
             # if we are around midnight we have to check the correct date (today, iesterday, tomorrow)
             datesched_min=self.now - datetime.timedelta( seconds=60*self.minelab)
             datesched_max=self.now + datetime.timedelta( seconds=60*self.minelab)
             if not (datesched_min <= self.ar_scheduledatetime and  self.ar_scheduledatetime <= datesched_max  ):
                 if self.now.time() < datetime.time(12):
-                    self.ar_scheduledatetime=datetime.datetime.combine(datesched_min.date(), fascia.emission_time)
+                    self.ar_scheduledatetime=datetime.datetime.combine(datesched_min.date(), fascia.emission_time,tzinfo=None)
                 else:
-                    self.ar_scheduledatetime=datetime.datetime.combine(datesched_max.date(), fascia.emission_time)
+                    self.ar_scheduledatetime=datetime.datetime.combine(datesched_max.date(), fascia.emission_time,tzinfo=None)
 
             self.ar_emission_done=fascia.emission_done
             yield fascia
@@ -108,7 +105,8 @@ class gest_spot(object):
 
     def get_prologhi(self):
 
-        prologhi= self.fascia.spot_set.filter(Q(start_date__lte=self.now) | Q(start_date__isnull=True),\
+        prologhi= self.fascia.spot_set.filter(Q(active__exact = True),\
+                                    Q(start_date__lte=self.now) | Q(start_date__isnull=True),\
                                     Q(end_date__gte=self.now) | Q(end_date__isnull=True),\
                                     Q(giorni__name__exact=self.giorno) , Q(prologo__exact=True)).order_by('priorita')
 
@@ -120,7 +118,8 @@ class gest_spot(object):
 
     def count_spots(self):
 
-        return self.fascia.spot_set.filter(Q(start_date__lte=self.now) | Q(start_date__isnull=True),\
+        return self.fascia.spot_set.filter(Q(active__exact = True),\
+                                    Q(start_date__lte=self.now) | Q(start_date__isnull=True),\
                                     Q(end_date__gte=self.now) | Q(end_date__isnull=True),\
                                     Q(giorni__name__exact=self.giorno)).exclude(prologo__exact=True)\
                                     .exclude(epilogo__exact=True).count()
@@ -129,7 +128,8 @@ class gest_spot(object):
 
     def get_spots(self):
 
-        spots=self.fascia.spot_set.filter(Q(start_date__lte=self.now) | Q(start_date__isnull=True),\
+        spots=self.fascia.spot_set.filter(Q(active__exact = True),\
+                                    Q(start_date__lte=self.now) | Q(start_date__isnull=True),\
                                     Q(end_date__gte=self.now) | Q(end_date__isnull=True),\
                                     Q(giorni__name__exact=self.giorno)).exclude(prologo__exact=True)\
                                     .exclude(epilogo__exact=True).order_by('priorita')
@@ -142,7 +142,8 @@ class gest_spot(object):
 
     def get_epiloghi(self):
 
-        epiloghi=self.fascia.spot_set.filter(Q(start_date__lte=self.now) | Q(start_date__isnull=True),\
+        epiloghi=self.fascia.spot_set.filter(Q(active__exact = True),\
+                                    Q(start_date__lte=self.now) | Q(start_date__isnull=True),\
                                     Q(end_date__gte=self.now) | Q(end_date__isnull=True),\
                                     Q(giorni__name__exact=self.giorno) , Q(epilogo__exact=True)).order_by('priorita')
         for epilogo in epiloghi:
@@ -192,19 +193,19 @@ class gest_spot(object):
                 # this work if LANG is set
                 #f.write(os.path.basename(filename.encode(sys.getfilesystemencoding())))
                 #f.write(os.path.basename(filename.encode("UTF-8")))
-                f.write(filename.encode("UTF-8"))
+                f.write(filename)
                 f.write("\n")
 
             # calcolo la lunghezza della fascia
             try:
-                filename=filename.encode("utf8")
-                onelength=mutagen.File(filename).info.length
-                logging.debug("SPOT: computed the partial time length: %d",onelength)
-                length=length+onelength
+                with open(filename,"rb") as mutagenfile:
+                    onelength=mutagen.File(mutagenfile).info.length
+                    logging.debug("SPOT: computed the partial time length: %d",onelength)
+                    length=length+onelength
             except:
 
                 logging.error( "SPOT: error establish time length; use an estimation %s", filename)
-       	length=length+30
+       	        length=length+30      # default for one spot
 
         self.ar_length=length
         logging.debug("SPOT: computed total time length: %d",self.ar_length)
