@@ -1,11 +1,6 @@
 #!/usr/bin/env python
 # GPL. (C) 2007 Paolo Patruno.
 
-from __future__ import division
-from __future__ import absolute_import
-from builtins import str
-from past.utils import old_div
-from builtins import object
 import logging
 import xmms,autoxmms
 from datetime import *
@@ -54,7 +49,7 @@ def ar_emitted(self):
     self.save()
 
 
-class ScheduleProgram(object):
+class ScheduleProgram:
     '''
     activate a schedule setting it for a time in the future
     '''
@@ -160,7 +155,7 @@ def ManageXmms (session,schedule):
 
 def secondi(delta):
     secondi=float(delta.seconds)
-    secondi=secondi+(old_div(delta.microseconds,100000.))
+    secondi=secondi+(delta.microseconds/100000.)
     # correggo i viaggi che si fa seconds
     if delta.days < 0 :
         secondi = secondi + (3600*24*delta.days)
@@ -168,7 +163,7 @@ def secondi(delta):
 
 
 
-class dummy_programma(object):
+class dummy_programma:
 
     def __init__(self):
         pass
