@@ -1,11 +1,9 @@
-from __future__ import absolute_import
-from builtins import object
 from django.contrib import admin
 from .models import Giorno, Configure, ProgramType, Show, Schedule, \
     PeriodicSchedule,AperiodicSchedule,Episode,Enclosure,ScheduleDone
 from autoradio.programs.models import ParentCategory, ChildCategory, MediaCategory
 from django import forms
-from django.utils.translation import ugettext_lazy
+from django.utils.translation import gettext_lazy
 import autoradio.settings
 import autoradio.mime
 
@@ -38,10 +36,10 @@ class MyEnclosureInlineFormset(forms.models.BaseInlineFormSet):
                                 return file
 
                             if not type:
-                                raise forms.ValidationError(ugettext_lazy("Browser say that Content-Type is not audio"))
+                                raise forms.ValidationError(gettext_lazy("Browser say that Content-Type is not audio"))
 
                             if not os.path.splitext(file.name)[1] in websuffix_audio:
-                                raise forms.ValidationError(ugettext_lazy("Doesn't have proper extension: .mp3, .wav, .ogg, .oga, .flac"))
+                                raise forms.ValidationError(gettext_lazy("Doesn't have proper extension: .mp3, .wav, .ogg, .oga, .flac"))
 
                             try:
                                 mime = ma.file(file.temporary_file_path())
@@ -50,7 +48,7 @@ class MyEnclosureInlineFormset(forms.models.BaseInlineFormSet):
                                 audio=False
 
                             if not audio:
-                                raise forms.ValidationError(ugettext_lazy("Not a valid audio file"))
+                                raise forms.ValidationError(gettext_lazy("Not a valid audio file"))
 
                             if autoradio.settings.require_tags_in_enclosure:
                                 #Check file if it is a known media file. The check is based on mutagen file test.
@@ -60,7 +58,7 @@ class MyEnclosureInlineFormset(forms.models.BaseInlineFormSet):
                                     audio = False
 
                                 if not audio:
-                                    raise forms.ValidationError(ugettext_lazy("Not a valid audio file: probably no tags present"))
+                                    raise forms.ValidationError(gettext_lazy("Not a valid audio file: probably no tags present"))
 
                         else:
 
@@ -71,10 +69,10 @@ class MyEnclosureInlineFormset(forms.models.BaseInlineFormSet):
                                 return file
 
                             if not type:
-                                raise forms.ValidationError(ugettext_lazy("Browser say that Content-Type is not audio ogg vorbis"))
+                                raise forms.ValidationError(gettext_lazy("Browser say that Content-Type is not audio ogg vorbis"))
 
                             if not os.path.splitext(file.name)[1] in websuffix_ogg:
-                                raise forms.ValidationError(ugettext_lazy("Doesn't have proper extension: .ogg, .oga"))
+                                raise forms.ValidationError(gettext_lazy("Doesn't have proper extension: .ogg, .oga"))
 
                             try:
                                 mime = ma.file(file.temporary_file_path())
@@ -83,7 +81,7 @@ class MyEnclosureInlineFormset(forms.models.BaseInlineFormSet):
                                 audio=False
 
                             if not audio:
-                                raise forms.ValidationError(ugettext_lazy("Not a valid ogg/oga vorbis audio file"))
+                                raise forms.ValidationError(gettext_lazy("Not a valid ogg/oga vorbis audio file"))
 
                             if autoradio.settings.require_tags_in_enclosure:
                                 #Check file if it is a known media file. The check is based on mutagen file test.
@@ -96,15 +94,15 @@ class MyEnclosureInlineFormset(forms.models.BaseInlineFormSet):
                                     sample_rate=0
 
                                 if not audio:
-                                    raise forms.ValidationError(ugettext_lazy("Not a valid ogg/oga vorbis audio file: probably no tags present"))
+                                    raise forms.ValidationError(gettext_lazy("Not a valid ogg/oga vorbis audio file: probably no tags present"))
 
                                 if not sample_rate == 44100:
-                                    raise forms.ValidationError(ugettext_lazy("Sample rate is Not 44100Hz: cannot use it in podcasting web interface"))
+                                    raise forms.ValidationError(gettext_lazy("Sample rate is Not 44100Hz: cannot use it in podcasting web interface"))
             
                         return file
 
                     else:
-                        raise forms.ValidationError(ugettext_lazy("Couldn't read uploaded file"))
+                        raise forms.ValidationError(gettext_lazy("Couldn't read uploaded file"))
 
             except AttributeError:
                 # annoyingly, if a subform is invalid Django explicity raises
@@ -112,7 +110,7 @@ class MyEnclosureInlineFormset(forms.models.BaseInlineFormSet):
                 pass
 
         if count < 1:
-            raise forms.ValidationError(ugettext_lazy('You must have at least one Enclosure'))
+            raise forms.ValidationError(gettext_lazy('You must have at least one Enclosure'))
 
 
 
@@ -139,12 +137,12 @@ class MyEnclosureAdminForm(forms.ModelForm):
                         return file
 
                     if not type:
-                        raise forms.ValidationError(ugettext_lazy("Content-Type is not audio/mpeg or audio/flac or video/ogg"))
+                        raise forms.ValidationError(gettext_lazy("Content-Type is not audio/mpeg or audio/flac or video/ogg"))
     
                     if not os.path.splitext(file.name)[1] in [".mp3",".wav",".ogg",".oga",".flac",
 							      ".Mp3",".Wav",".Ogg",".Oga",".Flac",
 							      ".MP3",".WAV",".OGG",".OGA",".FLAC" ]:
-                        raise forms.ValidationError(ugettext_lazy("Doesn't have proper extension: .mp3, .wav, .ogg, .oga, .flac"))
+                        raise forms.ValidationError(gettext_lazy("Doesn't have proper extension: .mp3, .wav, .ogg, .oga, .flac"))
                     #Check file if it is a known media file. The check is based on mutagen file test.
                     try:
                         audio = not mutagen.File(file.temporary_file_path()) is None
@@ -152,7 +150,7 @@ class MyEnclosureAdminForm(forms.ModelForm):
                         audio = False
 
                     if not audio:
-                        raise forms.ValidationError(ugettext_lazy("Not a valid audio file"))
+                        raise forms.ValidationError(gettext_lazy("Not a valid audio file"))
                     return file
 
                 else:
@@ -163,10 +161,10 @@ class MyEnclosureAdminForm(forms.ModelForm):
                         return file
 
                     if not type:
-                        raise forms.ValidationError(ugettext_lazy("Content-Type is not audio/oga or video/ogg"))
+                        raise forms.ValidationError(gettext_lazy("Content-Type is not audio/oga or video/ogg"))
 
                     if not os.path.splitext(file.name)[1] in [".ogg",".oga",".Ogg",".Oga",".OGG"]:
-                        raise forms.ValidationError(ugettext_lazy("Doesn't have proper extension: .ogg, .oga"))
+                        raise forms.ValidationError(gettext_lazy("Doesn't have proper extension: .ogg, .oga"))
                     #Check file if it is a known media file. The check is based on mutagen file test.
                     try:
                         mut=mutagen.File(file.temporary_file_path())
@@ -178,15 +176,15 @@ class MyEnclosureAdminForm(forms.ModelForm):
                         sample_rate=0
 
                     if not audio:
-                        raise forms.ValidationError(ugettext_lazy("Not a valid audio file"))
+                        raise forms.ValidationError(gettext_lazy("Not a valid audio file"))
 
                     if not sample_rate == 44100:
-                        raise forms.ValidationError(ugettext_lazy("Sample rate is Not 44100Hz: cannot use it in podcasting web interface"))
+                        raise forms.ValidationError(gettext_lazy("Sample rate is Not 44100Hz: cannot use it in podcasting web interface"))
             
                     return file
                 
 	    else:
-		    raise forms.ValidationError(ugettext_lazy("Couldn't read uploaded file"))
+		    raise forms.ValidationError(gettext_lazy("Couldn't read uploaded file"))
 
 
 class CategoryInline(admin.StackedInline):
@@ -301,7 +299,7 @@ class ShowAdmin(admin.ModelAdmin):
     prepopulated_fields = {'slug': ("title",)}
 
     fieldsets = (
-        (None, {'fields': ('title','slug','length','type','production',\
+        (None, {'fields': ('active','title','slug','length','type','production',\
                                'organization','link','description','author')}),
 
         ('Podcast options', {
@@ -316,9 +314,11 @@ class ShowAdmin(admin.ModelAdmin):
         )
 
 
-    list_display = ('title',)
-    #list_filter = ['end_date',]
-    search_fields = ['title',]
+    list_display = ('active','slug','title','description')
+    list_editable = ('active','title','description')
+    list_display_links = ('slug',)
+    list_filter = ['active','organization','author__username',]
+    search_fields = ['title','description']
 
 #    is better without EpisodeInline and start from Episode 
 #    inlines = [
@@ -384,7 +384,7 @@ class ScheduleAdmin(admin.ModelAdmin):
     list_display = ('episode', 'emission_date'\
                         ,'was_scheduled_today')
     list_filter = ['emission_date']
-    search_fields = ['episode','emission_date']
+    search_fields = ['episode__title','emission_date']
     date_hierarchy = 'emission_date'
 
 admin.site.register(Schedule, ScheduleAdmin)
@@ -393,21 +393,21 @@ admin.site.register(Schedule, ScheduleAdmin)
 class PeriodicScheduleAdmin(admin.ModelAdmin):
     list_display = ('start_date','end_date','time')
     list_filter = ['start_date','end_date','time','giorni']
-    search_fields = ['playlist','giorni']
+    search_fields = ['show__title','giorni__name']
     date_hierarchy = 'start_date'
 
 admin.site.register(PeriodicSchedule, PeriodicScheduleAdmin)
 
 class AperiodicScheduleAdmin(admin.ModelAdmin):
     list_display = ('emission_date','show')
-    search_fields = ['show']
+    search_fields = ['show__title']
     date_hierarchy = 'emission_date'
 
 admin.site.register(AperiodicSchedule, AperiodicScheduleAdmin)
 
 class ScheduleDoneAdmin(admin.ModelAdmin):
     list_display = ('emission_done','schedule','enclosure')
-    search_fields = ['enclosure']
+    search_fields = ['enclosure__title']
     date_hierarchy = 'emission_done'
 
 admin.site.register(ScheduleDone, ScheduleDoneAdmin)
