@@ -1,11 +1,6 @@
-from __future__ import absolute_import
 # Create your views here.
 
-from future import standard_library
-standard_library.install_aliases()
-from builtins import str
-from builtins import range
-from django.shortcuts import render_to_response
+from django.shortcuts import render
 from .models import Schedule
 from django.http import HttpResponse,HttpResponseRedirect
 from datetime import date,datetime,timedelta,time
@@ -17,7 +12,7 @@ import os
 
 #from django.forms.extras.widgets import SelectDateWidget
 from .widgets import MySelectDateWidget
-from django.utils.translation import ugettext_lazy
+from django.utils.translation import gettext_lazy
 
 #----------------------------------------------------
 # section for programs
@@ -42,7 +37,7 @@ def index(request):
     #    print ("ss=",ss)
     #    for sss in ss:
     #        print ("sss=",sss)
-    return render_to_response('schedule/index.html', {'schedules': scheds})
+    return render(request,'schedule/index.html', {'schedules': scheds})
 
 
 def stato(request):
@@ -50,14 +45,14 @@ def stato(request):
         
     xmmsweb=""
     try:
-        url=urllib.request.urlopen("http://"+autoradio.autoradio_config.XMMSHOST+":8888/")
-        for line in url:
-            xmmsweb=xmmsweb+line
+        with urllib.request.urlopen("http://"+autoradio.autoradio_config.XMMSHOST+":8888/") as response:
+            for line in response:
+                xmmsweb=xmmsweb+line
     except:
         xmmsweb="<p>Error getting player status !!</p>"
         xmmsweb=xmmsweb+"<p>Start autoradiod or verify settings</p>"
 
-    return render_to_response('xmms/index.html', {'xmmsweb': xmmsweb,})
+    return render(request,'xmms/index.html', {'xmmsweb': xmmsweb,})
 
 
 def dbusstato(request):
@@ -72,7 +67,7 @@ def dbusstato(request):
         except:
             htmlresponse +="<p>Error getting player status !!</p>"
             htmlresponse +=htmlresponse+"<p>Start autoradiod or verify settings</p>"
-            return render_to_response('xmms/index.html', {'xmmsweb': htmlresponse,})
+            return render(request,'xmms/index.html', {'xmmsweb': htmlresponse,})
     else:
         return stato(request)
         #htmlresponse += "Invalid player for dbus interface"
@@ -127,7 +122,7 @@ def dbusstato(request):
         htmlresponse +=htmlresponse+"<p>Start autoradiod or verify settings</p>"
         
     del mp
-    return render_to_response('xmms/index.html', {'xmmsweb': htmlresponse,})
+    return render(request,'xmms/index.html', {'xmmsweb': htmlresponse,})
 
 
 
@@ -156,14 +151,15 @@ def decode(code):
 
 class ExtremeForm(forms.Form):
 
-    initial_start=date.today()-timedelta(days=10)
-    initial_end=date.today()
+    def  initial_start ():
+        return date.today()-timedelta(days=10)
+    def initial_end ():
+        return date.today()
 
-#    datetime_start = forms.DateTimeField(required=True,initial=initial_start,widget=SelectDateWidget(years=(2010,etc)))
-#    datetime_end = forms.DateTimeField(required=True,initial=initial_end,widget=SelectDateWidget(years=(2010,etc)))
-    datetime_start = forms.DateTimeField(required=True,initial=initial_start,widget=MySelectDateWidget(),label=ugettext_lazy("Starting date & time"),help_text=ugettext_lazy("Elaborate palimpsest starting from this date and time"))
-
-    datetime_end = forms.DateTimeField(required=True,initial=initial_end,widget=MySelectDateWidget(),label=ugettext_lazy("Ending date & time"),help_text=ugettext_lazy("Elaborate palimpsest ending to this date and time"))
+    #    datetime_start = forms.DateTimeField(required=True,initial=initial_start,widget=SelectDateWidget(years=(2010,etc)))
+    #    datetime_end = forms.DateTimeField(required=True,initial=initial_end,widget=SelectDateWidget(years=(2010,etc)))
+    datetime_start = forms.DateTimeField(required=True,initial=initial_start,widget=MySelectDateWidget(),label=gettext_lazy("Starting date & time"),help_text=gettext_lazy("Elaborate palimpsest starting from this date and time"))
+    datetime_end = forms.DateTimeField(required=True,initial=initial_end,widget=MySelectDateWidget(),label=gettext_lazy("Ending date & time"),help_text=gettext_lazy("Elaborate palimpsest ending to this date and time"))
 
 def programsbook(request):
 
@@ -186,14 +182,14 @@ def programsbook(request):
 
             # time constants
             now=datetime.now()
-            minelab=1
+            minelab=60
 
 
             datetime_start=form.cleaned_data['datetime_start']
             datetime_end=form.cleaned_data['datetime_end']
 
-            datetime_start = datetime.combine(datetime_start.date(),time(00))
-            datetime_end = datetime.combine(datetime_end.date(),time(23,59))
+            datetime_start = datetime.combine(datetime_start.date(),time(00),tzinfo=None)
+            datetime_end = datetime.combine(datetime_end.date(),time(23,59),tzinfo=None)
 
             #datetime_start=(now-timedelta(days=4))
             #datetime_end=now
@@ -255,7 +251,7 @@ def programsbook(request):
 
                 dati.append([str(pdatetime_start.date()),Paragraph(title, styles["Normal"]),
                              pdatetime_start.time().strftime("%H:%M"),pdatetime_end.time().strftime("%H:%M"),
-                             Paragraph(type, styles["Normal"]),Paragraph(subtype, styles["Normal"]),production,note])
+                             Paragraph(type, styles["Normal"]),Paragraph(subtype, styles["Normal"]),production,""]) #note removed
 
 
             #dati.append(["totale","fine"])
@@ -275,7 +271,7 @@ def programsbook(request):
     else:
         form = ExtremeForm() # An unbound form
 
-    return render_to_response('palimpsest/extreme.html', {
+    return render(request,'palimpsest/extreme.html', {
         'form': form})
 
 
@@ -385,8 +381,8 @@ class episode_sitemap(ListView):
         self.queryset=Episode.objects.published().filter(show__slug__exact=self.slug).order_by('-date')
         return super(episode_sitemap, self).get(request, *args, **kwargs)
 
-    def render_to_response(self, context, **kwargs):
-        return super(episode_sitemap, self).render_to_response(context,
+    def render(request,self, context, **kwargs):
+        return super(episode_sitemap, self).render(request,context,
                         content_type='application/xml', **kwargs)
 
 
@@ -431,8 +427,8 @@ class show_list_feed(ListView):
         self.queryset=Episode.objects.filter(show__slug__exact=slug).order_by('-date')[0:21]
         return super(show_list_feed, self).get(request, *args, **kwargs)
 
-    def render_to_response(self, context, **kwargs):
-        return super(show_list_feed, self).render_to_response(context,
+    def render(request,self, context, **kwargs):
+        return super(show_list_feed, self).render(request,context,
                         content_type='application/xml', **kwargs)
 
 
@@ -462,8 +458,8 @@ class show_list_media(ListView):
         self.queryset=Episode.objects.filter(show__slug__exact=self.slug).order_by('-date')[0:21]
         return super(show_list_media, self).get(request, *args, **kwargs)
 
-    def render_to_response(self, context, **kwargs):
-        return super(show_list_media, self).render_to_response(context,
+    def render(request,self, context, **kwargs):
+        return super(show_list_media, self).render(request,context,
                         content_type='application/xml', **kwargs)
 
 
@@ -492,6 +488,6 @@ class show_list_atom(ListView):
         self.queryset=Episode.objects.filter(show__slug__exact=self.slug).order_by('-date')[0:21]
         return super(show_list_atom, self).get(request, *args, **kwargs)
 
-    def render_to_response(self, context, **kwargs):
+    def render(request,self, context, **kwargs):
         return super(show_list_atom, self).render_to_response(context,
                         content_type='application/xml', **kwargs)
